query getFinancialData($symbol: String!) {
    symbol(symbol: $symbol) {
        symbol
        id
        ratiosData {
            reportingCurrency
            currencySymbol
            __typename
        }
        financialTabData {
            Annual {
                periodEndDate
                fiscalYear
                periodType
                periodLength
                periodUnit
                incomeStatement {
                    source
                    periodLength
                    periodUnit
                    updateType
                    statementDate
                    auditorName
                    auditorOpinion
                    sourceDate
                    SREV
                    SPRE
                    RNII
                    RRGL
                    SIIB
                    SORE
                    RTLR
                    SCOR
                    SGRP
                    EFEX
                    EDOE
                    STIE
                    ENII
                    ELLP
                    SIAP
                    SLBA
                    EPAC
                    SSGA
                    ERAD
                    SDPR
                    SINN
                    SUIE
                    SOOE
                    ETOE
                    SOPI
                    SNIN
                    NGLA
                    NAFC
                    SNII
                    SNIE
                    SONT
                    EIBT
                    TTAX
                    TIAT
                    CMIN
                    CEIA
                    CGAP
                    NIBX
                    STXI
                    NINC
                    SANI
                    CIAC
                    XNIC
                    SDAJ
                    SDNI
                    SDWS
                    SDBF
                    DDPS1
                    VDES
                    __typename
                }
                balanceSheet {
                    source
                    updateType
                    statementDate
                    auditorName
                    auditorOpinion
                    sourceDate
                    ACSH
                    ACAE
                    ASTI
                    SCSI
                    AACR
                    ATRC
                    AITL
                    APPY
                    SOCA
                    ATCA
                    ACDB
                    SOEA
                    ANTL
                    APTC
                    ADEP
                    APPN
                    AGWI
                    AINT
                    SUPN
                    SINV
                    APRE
                    ALTR
                    SOLA
                    ADPA
                    SOAT
                    ATOT
                    LAPB
                    LPBA
                    LAEX
                    SPOL
                    LDBT
                    SOBL
                    LSTB
                    LSTD
                    LCLD
                    SOCL
                    LTCL
                    LLTD
                    LCLO
                    LTTD
                    STLD
                    SBDT
                    LMIN
                    SLTL
                    LTLL
                    SRPR
                    SPRS
                    SCMS
                    QPIC
                    QRED
                    QTSC
                    QEDG
                    QUGL
                    SOTE
                    QTLE
                    QTEL
                    QTCO
                    QTPO
                    STBP
                    __typename
                }
                cashFlowStatement {
                    source
                    periodLength
                    periodUnit
                    updateType
                    statementDate
                    auditorName
                    auditorOpinion
                    sourceDate
                    ONET
                    SDED
                    SAMT
                    OBDT
                    SNCI
                    OCRC
                    OCPD
                    SCTP
                    SCIP
                    SOCF
                    OTLO
                    SCEX
                    SICF
                    ITLI
                    SFCF
                    FCDP
                    FPSS
                    FPRD
                    FTLF
                    SFEE
                    SNCC
                    __typename
                }
                __typename
            }
        Interim {
            periodEndDate
            fiscalYear
            periodType
            periodLength
            periodUnit
            incomeStatement {
                source
                periodLength
                periodUnit
                updateType
                statementDate
                auditorName
                auditorOpinion
                sourceDate
                SREV
                SPRE
                RNII
                RRGL
                SIIB
                SORE
                RTLR
                SCOR
                SGRP
                EFEX
                EDOE
                STIE
                ENII
                ELLP
                SIAP
                SLBA
                EPAC
                SSGA
                ERAD
                SDPR
                SINN
                SUIE
                SOOE
                ETOE
                SOPI
                SNIN
                NGLA
                NAFC
                SNII
                SNIE
                SONT
                EIBT
                TTAX
                TIAT
                CMIN
                CEIA
                CGAP
                NIBX
                STXI
                NINC
                SANI
                CIAC
                XNIC
                SDAJ
                SDNI
                SDWS
                SDBF
                DDPS1
                VDES
                __typename
            }
            balanceSheet {
                source
                updateType
                statementDate
                auditorName
                auditorOpinion
                sourceDate
                ACSH
                ACAE
                ASTI
                SCSI
                AACR
                ATRC
                AITL
                APPY
                SOCA
                ATCA
                ACDB
                SOEA
                ANTL
                APTC
                ADEP
                APPN
                AGWI
                AINT
                SUPN
                SINV
                APRE
                ALTR
                SOLA
                ADPA
                SOAT
                ATOT
                LAPB
                LPBA
                LAEX
                SPOL
                LDBT
                SOBL
                LSTB
                LSTD
                LCLD
                SOCL
                LTCL
                LLTD
                LCLO
                LTTD
                STLD
                SBDT
                LMIN
                SLTL
                LTLL
                SRPR
                SPRS
                SCMS
                QPIC
                QRED
                QTSC
                QEDG
                QUGL
                SOTE
                QTLE
                QTEL
                QTCO
                QTPO
                STBP
                __typename
            }
            cashFlowStatement {
                source
                periodLength
                periodUnit
                updateType
                statementDate
                auditorName
                auditorOpinion
                sourceDate
                ONET
                SDED
                SAMT
                OBDT
                SNCI
                OCRC
                OCPD
                SCTP
                SCIP
                SOCF
                OTLO
                SCEX
                SICF
                ITLI
                SFCF
                FCDP
                FPSS
                FPRD
                FTLF
                SFEE
                SNCC
                __typename
            }
            __typename
        }
        __typename
        }
    __typename
    }
}
